(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    190056,       3553]
NotebookOptionsPosition[    186116,       3494]
NotebookOutlinePosition[    186535,       3511]
CellTagsIndexPosition[    186492,       3508]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"269817a4-19bf-4f73-935d-a903718166e6"],

Cell["Chapter 3, Section 3.14, Figure 3.33", "Section",
 CellChangeTimes->{{3.8585084755718517`*^9, 
  3.858508476126536*^9}},ExpressionUUID->"2a5a0ceb-7fdd-4994-b729-\
1bb38f7b7d96"],

Cell["\<\
Here we calculate the shifted locations of the Lagrange equilibrium points \
under the influence of an inertial drag force (see Sect.3.14.3).\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.858508610587311*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4f4b0557-04b1-4c6c-8aba-50cc0ae626e9"],

Cell["\<\
First we define a function to calculate the locations of the classical points \
for a given value of \[Mu].\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.858508673258671*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1a77f7cb-a374-455c-b874-934bbe0cd5ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LagFind", "[", "\[Mu]_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "r1", ",", "r2", ",", "L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5", 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"\[Mu]", "/", 
          RowBox[{"(", 
           RowBox[{"3", "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "3"}], ")"}]}]}], ",", 
      RowBox[{"\[Beta]", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"7", "/", "12"}], ")"}]}], "*", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"7", "/", "12"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "2"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"13223", "/", "20736"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "/", 
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Mu]"}], ")"}]}], ")"}], "^", "3"}]}]}]}]}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"L1", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", "\[Mu]", "-", 
         RowBox[{"(", 
          RowBox[{"r2", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "-", "r2"}], ")"}], "^", "2"}]}], "+", "1", 
                  "-", "r2"}], ")"}]}], "-", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r2", "^", "2"}]}], "+", "r2"}], ")"}]}]}], "==", 
              "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r2", ",", "\[Alpha]"}], "}"}]}], "]"}]}], ")"}]}], ",",
         "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "-", "\[Mu]", "+", 
         RowBox[{"(", 
          RowBox[{"r2", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "r2"}], ")"}], "^", "2"}]}], "+", "1", 
                  "+", "r2"}], ")"}]}], "+", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r2", "^", "2"}]}], "+", "r2"}], ")"}]}]}], "==", 
              "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r2", ",", "\[Alpha]"}], "}"}]}], "]"}]}], ")"}]}], ",",
         "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L3", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "\[Mu]"}], "-", 
         RowBox[{"(", 
          RowBox[{"r1", "/.", "\[IndentingNewLine]", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "-", "\[Mu]"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{"r1", "^", "2"}]}], "+", "r1"}], ")"}]}], "+", 
               RowBox[{"\[Mu]", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "+", "r1"}], ")"}], "^", "2"}]}], "+", "1", 
                  "+", "r1"}], ")"}]}]}], "==", "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"r1", ",", 
               RowBox[{"1", "+", "\[Beta]"}]}], "}"}]}], "]"}]}], ")"}]}], 
        ",", "0"}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"L4", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"L5", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.5", "-", "\[Mu]"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sqrt", "[", "3", "]"}]}], "/", "2"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"L1", ",", "L2", ",", "L3", ",", "L4", ",", "L5"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.855478187690501*^9, 3.855478312010507*^9}, {
   3.855478378175737*^9, 3.855478469585854*^9}, {3.85547850813591*^9, 
   3.8554785222565613`*^9}, {3.855478554441102*^9, 3.855478598512735*^9}, {
   3.855478632261034*^9, 3.855478646301046*^9}, {3.8554786878212633`*^9, 
   3.8554787628363857`*^9}, {3.8554787949828053`*^9, 
   3.8554788551012487`*^9}, {3.855479274427092*^9, 3.855479395597623*^9}, {
   3.855480511995549*^9, 3.855480514123427*^9}, {3.85548062481107*^9, 
   3.855480626145108*^9}, 3.855576238824217*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"33166915-659f-43a3-a668-6b1f149a2bbf"],

Cell["We will denote these locations by red dots on the plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.858508708853166*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ba963480-77f1-4d9a-bede-b78d0c2e1c06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lpts", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Point", "[", "#", "]"}], "&"}], ",", 
        RowBox[{"LagFind", "[", "0.2", "]"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.8585051549472523`*^9, {3.858505319196226*^9, 3.858505319719104*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"b22ea0db-be88-4184-955d-2cc7d67fdbd2"],

Cell["Define the two axes ...", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.85850873945303*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"53e2361e-d680-47ca-b5f2-028cd34b7ed9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axes", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1.6"}], ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1.6", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", "1.6"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1.6"}], "}"}]}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.858505351339841*^9, 3.858505361150548*^9}, {
  3.85850642561946*^9, 3.858506499824933*^9}, {3.858506551412814*^9, 
  3.858506565495504*^9}, {3.858506666052526*^9, 3.8585066754236937`*^9}, {
  3.858506961759369*^9, 3.858506986402337*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"91c6c36a-2bef-4abf-a636-32fde6ae1390"],

Cell["... and the location of the two masses.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.858508767999118*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8769580b-7ac5-43b4-bbb9-379c51f28402"],

Cell[BoxData[
 RowBox[{
  RowBox[{"masses", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.13", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "\[Mu]2"}], ",", "0"}], "}"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "0.05", "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"1", "-", "\[Mu]2"}], ",", "0"}], "}"}], "]"}]}], "}"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8585068567899857`*^9, 3.8585069552926197`*^9}, 
   3.858506989928576*^9, {3.858507022496292*^9, 3.858507037897629*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"1f290f11-fbe1-4c32-9ac4-0ff9f49cef7f"],

Cell["Set the mass to be 0.2.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.858508789493712*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2c48fec4-9be4-4185-9bfa-b6af1fdb44a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Mu]2", "=", "0.2"}], ";"}]], "Input",
 CellChangeTimes->{{3.858502291193676*^9, 3.8585022990329733`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"d3cf6e69-ee72-405d-bc7a-2556fa316fdc"],

Cell[TextData[{
 "Define functions to calculate the values of ",
 StyleBox["r",
  FontSlant->"Italic"],
 ", ",
 StyleBox["r",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5bb912cd-97e5-48ea-b27c-0a449187e506"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "8499c4fd-5968-4123-b7c0-4b8638c5aa5f"],
 " for given values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y",
  FontSlant->"Italic"],
 ".  The definitions of ",
 StyleBox["r",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "9c85d625-ae63-44d3-ab0f-21e0fed7ab30"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "08499a6c-a2a4-447b-9b57-5f3ddecf5eb9"],
 " are taken from Eqs.(3.8) and (3.9)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"619bad11-b858-4312-bc43-5466bf17a6b3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8585017777070007`*^9, 3.8585018034446983`*^9}, {
  3.858501921571754*^9, 3.858501928290724*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"49876f28-cc85-4050-b59c-e1ca11f406a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r1", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "+", "\[Mu]2"}], ")"}], "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.858501931531754*^9, 3.8585019780898247`*^9}, {
  3.858502302798571*^9, 3.858502304147756*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"240f5900-c048-410b-89d1-5243c2e82cb0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r2", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
   RowBox[{"Sqrt", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", 
        RowBox[{"(", 
         RowBox[{"1", "-", "\[Mu]2"}], ")"}]}], ")"}], "^", "2"}], "+", 
     RowBox[{"y", "^", "2"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.858501981180147*^9, 3.858502037744763*^9}, {
  3.8585023065782747`*^9, 3.8585023076724167`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"007e1a33-5a6f-4a37-8b21-5da230b9ee9b"],

Cell[TextData[{
 "The paths of the five points are given by Eq.(3.250).  We use ",
 StyleBox["ContourPlot",
  FontWeight->"Bold"],
 " to calculate this path."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.858509157041147*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"566e08fa-5b52-4766-9bdd-04f2a347f8ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dragpath", "=", 
  RowBox[{"ContourPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "^", "2"}], "*", 
       RowBox[{
        RowBox[{"r1", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "^", "3"}], "*", 
       RowBox[{
        RowBox[{"r2", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "^", "3"}]}], "+", 
      RowBox[{"\[Mu]2", "*", 
       RowBox[{
        RowBox[{"r1", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "\[Mu]2"}], ")"}], "*", "x"}], "-", 
         RowBox[{
          RowBox[{"r", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "^", "2"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "\[Mu]2"}], ")"}], "*", 
       RowBox[{
        RowBox[{"r2", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "^", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]2", "*", "x"}], "+", 
         RowBox[{
          RowBox[{"r", "[", 
           RowBox[{"x", ",", "y"}], "]"}], "^", "2"}]}], ")"}]}]}], "==", 
     "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", "1.5"}], ",", "1.5"}], "}"}], ",", 
    RowBox[{"PlotPoints", "->", "200"}], ",", 
    RowBox[{"Frame", "->", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8585021342239237`*^9, 3.8585022388241034`*^9}, {
   3.858502316192223*^9, 3.858502399216683*^9}, {3.858504726572969*^9, 
   3.858504816016676*^9}, {3.858504854749627*^9, 3.8585048552887907`*^9}, {
   3.858505026350504*^9, 3.858505031914175*^9}, {3.85850517518159*^9, 
   3.858505216177737*^9}, 3.85850526239497*^9},
 CellLabel->"In[9]:=",ExpressionUUID->"89b32da6-f2fe-4720-a6c3-39f0c50322b7"],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJxcnXdcTf8fx7PJDg0jRVaJrETjTbaikO0rUlZEwwgZRaI0VaIoRRmhiLTe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    "], {{}, {}, 
     TagBox[
      TooltipBox[
       {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
        LineBox[CompressedData["
1:eJwl2kMUIMqSBcDftm3btm3btm3btm3btm3b9uuJPrOIU5vaFjLzJmjYrmLb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         "]], LineBox[CompressedData["
1:eJwN02PDFgYAAMAn680tt7i4jGXbtu1ats0t17Jt27Zt28buw/2ES9ywXcW2
wQKBQLHggcCx8IHAcU5wklOc5gxnOcd5LnCRS1zmCle5xnVucJNb3OYOd7nH
fR7wkEc85glPecZzXvCSV7zmDW95x3s+8JFPfOYLX/nGd37wk18EIgQCwQhO
CEISitCEISzhCE8EgohIJCIThahEIzox+I2YxCI2cYhLPOKTgN9JSCISk4Sk
JOMPkpOClKQiNWn4k7SkIz0ZyEgmMpOFrGTjL7KTg5zkIjd5yEs+8lOAghSi
MEUoSjGKU4KSlKI0ZShLOcpTgYpUojJVqEo1qlODmtSiNnWoSz3q04CGNKIx
TWhKM5rTgpa0ojVtaEs72vM3HehIJzrTha50ozs96EkvetOHvvSjPwMYyCAG
M4ShDGM4IxjJKEYzhrH8w7+MYzwTmMgkJjOFqUzjP6Yzg5nMYjZzmMs85rOA
hSxiMUtYyjKWs4KVrGI1a1jLOtazgY1sYjNb2Mo2trODnexiN3vYyz72c4CD
HOIwRzjKMY5zgpOc4jRnOMs5znOBi1ziMle4yjWuc4Ob3OI2d7jLPe7zgIc8
4jFPeMoznvOCl7ziNW94yzve84GPfOIzX/jKN77zg5/8IhDkP8EJQUhCEZow
hCUc4YlAEBGJRGSiEJVoRCcGvxGTWMQmDnGJR3wS8DsJSURikpCUZPxBclKQ
klSkJg1/kpZ0pCcDGclEZrKQlWz8RXZykJNc5CYPeclHfgpQkEIUpghFKUZx
SlCSUpSmDGUpR3kqUJFKVKYKValGdWpQk1rUpg51qUd9GtCQRjSmCU1pRnNa
0JJWtKYNbWlHe/6mAx3pRGe60JVudKcHPelFb/rQl370ZwADGcRghjCUYQxn
BCMZxWjGMJZ/+JdxjGcCE5nEZKYwlWn8x3RmMJNZzGYOc5nHfBawkEUsZglL
WcZyVrCSVaxmDWtZx3o2sJFNbGYLW9nGdnawk13sZg972cd+DnCQQxzmCEc5
xnFOcJJTnOYMZznHeS5wkUtc5gpXucZ1bnCTW9zmDne5x30e8JBHPOYJT3nG
c17wkle85g1vecd7PvCRT3zmC1/5xnd+8JNfBCL6T3BCEJJQhCYMYQlHeCIQ
REQiEZkoROV/MJtLCg==
         "]], LineBox[CompressedData["
1:eJwNxFVgFQQAAMCHgPTAsTE2BjJauhuRRro7R6NsdKOidIcgSiqNdCvdjdIo
3al0g3Ifd1HRsXVi4gQCgSQKThYIpCSEUFIRRmrCiSANkaQlHR+TnigykJFM
ZCYLWcnGJ2QnBznJRW7ykJd85KcABSlEYYpQlGIUpwQlKcWnlOYzylCWcpSn
AhWpRGU+pwpVqUZ1alCTWtSmDnWpR30a0JBGNKYJTWlGc1rQkla0Jpo2tKUd
7elARzrRmS/4ki7EEEtXutGdHvSkF73pQ1/60Z8BDGQQX/E13zCYb/mOIQxl
GMMZwUhGMZoxjGUc45nARCYxme+ZwlR+YBo/8hPTmcFMZjGbOfzML8xlHvNZ
wEIWsZgl/MpSlrGcFaxkFatZw1rWsZ4NbOQ3fmcTm9nCVraxnR3sZBe72cNe
9rGfAxzkEIc5wlH+4E+OcZwTnOQUpznDWf7ib85xngtc5BKXucJVrnGdG9zk
Fre5w13ucZ9/+JcHPOQRj3nCU57xnBe85BWvecNb3vEf/xMICgTi8AFxiUd8
PiQBCUlEYpKQlGQEkZwUfEQwKQkhlFSEkZpwIkhDJO8B7TOP6Q==
         "]]},
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"-", "0.8`"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8`"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], 
              RowBox[{"3", "/", "2"}]], " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"0.2`", " ", 
                   TagBox["x", HoldForm]}], "+", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], "+", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}], ")"}]}], "+", 
           RowBox[{"0.2`", " ", 
             RowBox[{"(", 
               RowBox[{
                 RowBox[{"0.8`", " ", 
                   TagBox["x", HoldForm]}], "-", 
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], "-", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2`", "\[VeryThinSpace]"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], 
              RowBox[{"3", "/", "2"}]]}], "+", 
           RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8`"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], 
              RowBox[{"3", "/", "2"}]], " ", 
             RowBox[{"(", 
               RowBox[{
                 SuperscriptBox[
                  TagBox["x", HoldForm], "2"], "+", 
                 SuperscriptBox[
                  TagBox["y", HoldForm], "2"]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2`", "\[VeryThinSpace]"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], 
              RowBox[{"3", "/", "2"}]]}]}], "\[Equal]", "0"}]],
      Annotation[#, (-0.8) ((-0.8 + HoldForm[$CellContext`x])^2 + 
           HoldForm[$CellContext`y]^2)^Rational[3, 2] (
          0.2 HoldForm[$CellContext`x] + HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2) + 
        0.2 (0.8 HoldForm[$CellContext`x] - HoldForm[$CellContext`x]^2 - 
          HoldForm[$CellContext`y]^2) ((0.2 + HoldForm[$CellContext`x])^2 + 
           HoldForm[$CellContext`y]^2)^
          Rational[3, 2] + ((-0.8 + HoldForm[$CellContext`x])^2 + 
           HoldForm[$CellContext`y]^2)^Rational[3, 2] (
          HoldForm[$CellContext`x]^2 + 
          HoldForm[$CellContext`y]^2) ((0.2 + HoldForm[$CellContext`x])^2 + 
           HoldForm[$CellContext`y]^2)^Rational[3, 2] == 0, 
       "Tooltip"]& ]}], {}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.858505265649638*^9, 3.8585053257104*^9, {3.858506626245798*^9, 
   3.858506647498547*^9}, 3.85850975856332*^9, 3.8909027700333443`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"45de3c19-81e3-422d-90f0-6382e6290312"]
}, Open  ]],

Cell["\<\
Note that there is an additional solution appearing as a circle close to the \
primary mass.  This has no physical significance to the calculation of \
interest and will be ignored.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.858509251451591*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5c8377fa-8d4b-4479-8815-9e730256c234"],

Cell["\<\
Display the path together with the two masses (the primary hides the \
non-physical, circular path), axes and the locations of the five, unshifted \
equilibrium points.  This Fig.3.33a.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.858509366652581*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5cd57b6e-1f62-4fea-99b4-25a7e99a26ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"dragpath", ",", "lpts", ",", "axes", ",", "masses"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.858505221247951*^9, 3.858505232255858*^9}, {
  3.858506507251317*^9, 3.858506508479664*^9}, {3.858507003112688*^9, 
  3.858507004717008*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"46d9d4b8-a4d9-45a5-b5bb-71b3b030bdd4"],

Cell[BoxData[
 GraphicsBox[{{GraphicsComplexBox[CompressedData["
1:eJxcnXdcTf8fx7PJDg0jRVaJrETjTbaikO0rUlZEwwgZRaI0VaIoRRmhiLTe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     "], {{}, {}, 
      TagBox[
       TooltipBox[
        {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
         LineBox[CompressedData["
1:eJwl2kMUIMqSBcDftm3btm3btm3btm3btm3b9uuJPrOIU5vaFjLzJmjYrmLb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          "]], LineBox[CompressedData["
1:eJwN02PDFgYAAMAn680tt7i4jGXbtu1ats0t17Jt27Zt28buw/2ES9ywXcW2
wQKBQLHggcCx8IHAcU5wklOc5gxnOcd5LnCRS1zmCle5xnVucJNb3OYOd7nH
fR7wkEc85glPecZzXvCSV7zmDW95x3s+8JFPfOYLX/nGd37wk18EIgQCwQhO
CEISitCEISzhCE8EgohIJCIThahEIzox+I2YxCI2cYhLPOKTgN9JSCISk4Sk
JOMPkpOClKQiNWn4k7SkIz0ZyEgmMpOFrGTjL7KTg5zkIjd5yEs+8lOAghSi
MEUoSjGKU4KSlKI0ZShLOcpTgYpUojJVqEo1qlODmtSiNnWoSz3q04CGNKIx
TWhKM5rTgpa0ojVtaEs72vM3HehIJzrTha50ozs96EkvetOHvvSjPwMYyCAG
M4ShDGM4IxjJKEYzhrH8w7+MYzwTmMgkJjOFqUzjP6Yzg5nMYjZzmMs85rOA
hSxiMUtYyjKWs4KVrGI1a1jLOtazgY1sYjNb2Mo2trODnexiN3vYyz72c4CD
HOIwRzjKMY5zgpOc4jRnOMs5znOBi1ziMle4yjWuc4Ob3OI2d7jLPe7zgIc8
4jFPeMoznvOCl7ziNW94yzve84GPfOIzX/jKN77zg5/8IhDkP8EJQUhCEZow
hCUc4YlAEBGJRGSiEJVoRCcGvxGTWMQmDnGJR3wS8DsJSURikpCUZPxBclKQ
klSkJg1/kpZ0pCcDGclEZrKQlWz8RXZykJNc5CYPeclHfgpQkEIUpghFKUZx
SlCSUpSmDGUpR3kqUJFKVKYKValGdWpQk1rUpg51qUd9GtCQRjSmCU1pRnNa
0JJWtKYNbWlHe/6mAx3pRGe60JVudKcHPelFb/rQl370ZwADGcRghjCUYQxn
BCMZxWjGMJZ/+JdxjGcCE5nEZKYwlWn8x3RmMJNZzGYOc5nHfBawkEUsZglL
WcZyVrCSVaxmDWtZx3o2sJFNbGYLW9nGdnawk13sZg972cd+DnCQQxzmCEc5
xnFOcJJTnOYMZznHeS5wkUtc5gpXucZ1bnCTW9zmDne5x30e8JBHPOYJT3nG
c17wkle85g1vecd7PvCRT3zmC1/5xnd+8JNfBCL6T3BCEJJQhCYMYQlHeCIQ
REQiEZkoROV/MJtLCg==
          "]], LineBox[CompressedData["
1:eJwNxFVgFQQAAMCHgPTAsTE2BjJauhuRRro7R6NsdKOidIcgSiqNdCvdjdIo
3al0g3Ifd1HRsXVi4gQCgSQKThYIpCSEUFIRRmrCiSANkaQlHR+TnigykJFM
ZCYLWcnGJ2QnBznJRW7ykJd85KcABSlEYYpQlGIUpwQlKcWnlOYzylCWcpSn
AhWpRGU+pwpVqUZ1alCTWtSmDnWpR30a0JBGNKYJTWlGc1rQkla0Jpo2tKUd
7elARzrRmS/4ki7EEEtXutGdHvSkF73pQ1/60Z8BDGQQX/E13zCYb/mOIQxl
GMMZwUhGMZoxjGUc45nARCYxme+ZwlR+YBo/8hPTmcFMZjGbOfzML8xlHvNZ
wEIWsZgl/MpSlrGcFaxkFatZw1rWsZ4NbOQ3fmcTm9nCVraxnR3sZBe72cNe
9rGfAxzkEIc5wlH+4E+OcZwTnOQUpznDWf7ib85xngtc5BKXucJVrnGdG9zk
Fre5w13ucZ9/+JcHPOQRj3nCU57xnBe85BWvecNb3vEf/xMICgTi8AFxiUd8
PiQBCUlEYpKQlGQEkZwUfEQwKQkhlFSEkZpwIkhDJO8B7TOP6Q==
          "]]},
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"-", "0.8`"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8`"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"0.2`", " ", 
                    TagBox["x", HoldForm]}], "+", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}]}], "+", 
            RowBox[{"0.2`", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"0.8`", " ", 
                    TagBox["x", HoldForm]}], "-", 
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], "-", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2`", "\[VeryThinSpace]"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], 
               RowBox[{"3", "/", "2"}]]}], "+", 
            RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "0.8`"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], 
               RowBox[{"3", "/", "2"}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                   TagBox["x", HoldForm], "2"], "+", 
                  SuperscriptBox[
                   TagBox["y", HoldForm], "2"]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                 RowBox[{
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"0.2`", "\[VeryThinSpace]"}], "+", 
                    TagBox["x", HoldForm]}], ")"}], "2"], "+", 
                   SuperscriptBox[
                    TagBox["y", HoldForm], "2"]}], ")"}], 
               RowBox[{"3", "/", "2"}]]}]}], "\[Equal]", "0"}]],
       Annotation[#, (-0.8) ((-0.8 + HoldForm[$CellContext`x])^2 + 
            HoldForm[$CellContext`y]^2)^Rational[3, 2] (
           0.2 HoldForm[$CellContext`x] + HoldForm[$CellContext`x]^2 + 
           HoldForm[$CellContext`y]^2) + 
         0.2 (0.8 HoldForm[$CellContext`x] - HoldForm[$CellContext`x]^2 - 
           HoldForm[$CellContext`y]^2) ((0.2 + HoldForm[$CellContext`x])^2 + 
            HoldForm[$CellContext`y]^2)^
           Rational[3, 2] + ((-0.8 + HoldForm[$CellContext`x])^2 + 
            HoldForm[$CellContext`y]^2)^Rational[3, 2] (
           HoldForm[$CellContext`x]^2 + 
           HoldForm[$CellContext`y]^2) ((0.2 + HoldForm[$CellContext`x])^2 + 
            HoldForm[$CellContext`y]^2)^Rational[3, 2] == 0, 
        "Tooltip"]& ]}], {}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], PointBox[{0.43807595853836606`, 0}], 
    PointBox[{1.2710486907398812`, 0}], PointBox[{-1.0828394642022434`, 0}], 
    PointBox[NCache[{0.3, Rational[1, 2] 3^Rational[1, 2]}, {0.3, 
      0.8660254037844386}]], 
    PointBox[NCache[{0.3, Rational[-1, 2] 3^Rational[1, 2]}, {
      0.3, -0.8660254037844386}]]}, {LineBox[{{-1.6, 0}, {1.6, 0}}], 
    LineBox[{{0, -1.6}, {0, 1.6}}]}, {
    {PointSize[0.13], PointBox[{-0.2, 0}]}, 
    {PointSize[0.05], PointBox[{0.8, 0}]}}},
  AspectRatio->1,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "GridLinesInFront" -> 
    True},
  PlotRange->{{-1.5, 1.5}, {-1.5, 1.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.858505233321971*^9, 3.858505328241741*^9, 3.858506509457932*^9, {
   3.85850657191276*^9, 3.858506583992362*^9}, {3.858506629247079*^9, 
   3.858506647528406*^9}, {3.858506679728863*^9, 3.8585066945138407`*^9}, {
   3.858507005369154*^9, 3.85850704231688*^9}, 3.8585097587254477`*^9, 
   3.8909027702680073`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"0a51d02a-fd1f-4400-85da-1ca2adf90500"]
}, Open  ]],

Cell[TextData[{
 "Now consider how we can illustrate the locations of the L3, L4 and L5 \
points for a given value of the drag constant ",
 Cell[BoxData[
  TemplateBox[<|"boxes" -> FormBox[
      RowBox[{
        OverscriptBox[
         StyleBox["k", "TI"], "_"], "/", 
        SubscriptBox["\[Mu]", "2"]}], TraditionalForm], "errors" -> {}, 
    "input" -> "{{\\bar k}/{\\mu_2}}", "state" -> "Boxes"|>,
   "TeXAssistantTemplate"]],
  CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
   3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
   3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}, {
   3.85850781742166*^9, 3.858507821030355*^9}, {3.858507960143367*^9, 
   3.858507976929194*^9}},ExpressionUUID->
  "aa5ebdb1-a9d5-415e-9b94-98b497bbc740"],
 ".  This is given by Eq.(3.251).  First we define the function given in the \
equation."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.8585093936556273`*^9}, {3.8585094386234083`*^9, 
  3.8585094857987432`*^9}, {3.858509525609679*^9, 3.8585096026043863`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6a1d5b80-6fb8-463f-9fa4-ebd868c96402"],

Cell[BoxData[
 RowBox[{
  RowBox[{"kbarmu", "[", "\[Theta]_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", " ", "Degree"}], "]"}], "*", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", "-", 
         RowBox[{"2", "*", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", " ", "Degree"}], "]"}]}]}], ")"}], "^", 
       RowBox[{"(", "1.5", ")"}]}]}], "-", "1"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.858507090416256*^9, 3.858507155737145*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"cf3dacee-daca-4d52-848b-4cbc375e69ec"],

Cell["Set the two labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.8585093936556273`*^9}, {3.8585094386234083`*^9, 
  3.8585094857987432`*^9}, {3.858509525609679*^9, 3.858509620663645*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"27bcb196-d05a-4225-af8a-36d255be8b6b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
FractionBox[
OverscriptBox[
StyleBox[\"k\", \"TI\"], \"_\"], 
SubscriptBox[\"\[Mu]\", \"2\"]], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"{{\\\\bar k}\\\\over{\\\\mu_2}}\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xlabel", "=", 
   RowBox[{
   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[\"\[Theta]\", \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\theta\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", "<>", "\"\< (deg.)\>\""}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.855640306242826*^9, 3.855640313202561*^9}, {
  3.855640391802243*^9, 3.855640398897621*^9}, {3.85564053863629*^9, 
  3.8556406145515633`*^9}, {3.856874675072912*^9, 3.856874721538768*^9}, {
  3.85850781742166*^9, 3.858507821030355*^9}, {3.858507960143367*^9, 
  3.858507976929194*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"e89ff1d2-af93-411f-8d50-89802fcbccdc"],

Cell["Plot the basic function.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.8585093936556273`*^9}, {3.8585094386234083`*^9, 
  3.8585094857987432`*^9}, {3.858509525609679*^9, 3.8585096482795477`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e8bd7189-1664-4837-86b4-8c0ffbf98e40"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"kbarmu", "[", "th", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"th", ",", "0", ",", "360"}], "}"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30", ",", "330"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameTicks", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", 
           RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "2"}], "}"}], ",", 
         "None"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "30", ",", "90", ",", "150", ",", "210", ",", "270", ",", "330"}], 
          "}"}], ",", "None"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"Frame", "->", "True"}], ",", 
    RowBox[{"FrameStyle", "->", 
     RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", 
    RowBox[{"FrameLabel", "->", 
     RowBox[{"{", 
      RowBox[{"xlabel", ",", "ylabel"}], "}"}]}], ",", 
    RowBox[{"RotateLabel", "->", "False"}], ",", 
    RowBox[{"LabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858507164679764*^9, 3.858507252217246*^9}, {
  3.858507478266535*^9, 3.858507502294153*^9}, {3.858507844325667*^9, 
  3.858507935915453*^9}, {3.8585080885707827`*^9, 3.85850809716477*^9}, {
  3.8585081528292923`*^9, 3.858508154360383*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"1880e32f-bf75-46af-97ea-314da286b414"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJw1mnk4Vd/790khSSWFkhQlREIRsm6SMs/TMZcM4ZzjHEmkIqRICAlFg9JA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       "]]},
     Annotation[#, "Charting`Private`Tag$3600#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{30.000000000000068`, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[FractionBox[OverscriptBox[StyleBox[\\\"k\\\", \\\"TI\\\"], \
\\\"_\\\"], SubscriptBox[\\\"\[Mu]\\\", \\\"2\\\"]], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"{{\\\\\\\\bar \
k}\\\\\\\\over{\\\\\\\\mu_2}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {-1, 
       FormBox[
        RowBox[{"-", "1"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}}, {}}, {{{30, 
       FormBox["30", TraditionalForm]}, {90, 
       FormBox["90", TraditionalForm]}, {150, 
       FormBox["150", TraditionalForm]}, {210, 
       FormBox["210", TraditionalForm]}, {270, 
       FormBox["270", TraditionalForm]}, {330, 
       FormBox["330", TraditionalForm]}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{30., 330.}, {-2.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.8585071964444857`*^9, 3.8585072537055264`*^9, {3.8585074905550823`*^9, 
   3.85850750344322*^9}, {3.858507946554517*^9, 3.858507979950583*^9}, 
   3.8585080978535423`*^9, 3.858508308854127*^9, 3.858509758867449*^9, 
   3.8909027704234333`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"865f7aaa-f14c-4c6f-bc56-143d9d96a96d"]
}, Open  ]],

Cell["Now add the locations of L3, L4 and L5 along with an axis.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.8585093936556273`*^9}, {3.8585094386234083`*^9, 
  3.8585094857987432`*^9}, {3.858509525609679*^9, 3.858509620663645*^9}, {
  3.858509657084297*^9, 3.858509677739683*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8a564021-a857-4618-9f06-c17486197e9d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newlpts", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"60", ",", "0"}], "}"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"180", ",", "0"}], "}"}], "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"300", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.8585051549472523`*^9, {3.858505319196226*^9, 3.858505319719104*^9}, {
   3.858508163001891*^9, 3.858508242154439*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"30013113-af3e-4096-b9a6-3bc2c09dd380"],

Cell[BoxData[
 RowBox[{
  RowBox[{"axis", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Line", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"30", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"330", ",", "0"}], "}"}]}], "}"}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.858508251517311*^9, 3.858508289719535*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"f17f958b-b731-4fad-92d7-b7b5791a4528"],

Cell["This is Fig.3.33b.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.858508501536807*^9, 3.8585085636072683`*^9}, {
  3.85850859387754*^9, 3.8585088253584747`*^9}, {3.858508907492058*^9, 
  3.858508954467018*^9}, {3.858509006695623*^9, 3.8585090407015133`*^9}, {
  3.8585090715700607`*^9, 3.8585093936556273`*^9}, {3.8585094386234083`*^9, 
  3.8585094857987432`*^9}, {3.858509525609679*^9, 3.858509620663645*^9}, {
  3.858509657084297*^9, 3.858509703555423*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b46149fd-578f-41b2-b501-1a970a1bd3fe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"kplot", ",", "newlpts", ",", "axis"}], "]"}]], "Input",
 CellChangeTimes->{{3.858508293263657*^9, 3.8585083034599667`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"432b31e8-6594-4599-b163-f3c2b9ddf8bf"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJw1mnk4Vd/790khSSWFkhQlREIRsm6SMs/TMZcM4ZzjHEmkIqRICAlFg9JA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        "]]},
      Annotation[#, "Charting`Private`Tag$3600#1"]& ]}, {}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], PointBox[{60, 0}], PointBox[{180, 0}],
     PointBox[{300, 0}]}, LineBox[{{30, 0}, {330, 0}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{30.000000000000068`, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[FractionBox[OverscriptBox[StyleBox[\\\"k\\\", \\\"TI\\\"], \
\\\"_\\\"], SubscriptBox[\\\"\[Mu]\\\", \\\"2\\\"]], TraditionalForm], \
\\\"errors\\\" -> {}, \\\"input\\\" -> \\\"{{\\\\\\\\bar \
k}\\\\\\\\over{\\\\\\\\mu_2}}\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", HoldForm], 
      TraditionalForm], None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[\\\"\[Theta]\\\", \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \
\\\"\\\\\\\\theta\\\", \\\"state\\\" -> \
\\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\) (deg.)\"", HoldForm], 
      TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{{{-2, 
       FormBox[
        RowBox[{"-", "2"}], TraditionalForm]}, {-1, 
       FormBox[
        RowBox[{"-", "1"}], TraditionalForm]}, {0, 
       FormBox["0", TraditionalForm]}, {1, 
       FormBox["1", TraditionalForm]}, {2, 
       FormBox["2", TraditionalForm]}}, {}}, {{{30, 
       FormBox["30", TraditionalForm]}, {90, 
       FormBox["90", TraditionalForm]}, {150, 
       FormBox["150", TraditionalForm]}, {210, 
       FormBox["210", TraditionalForm]}, {270, 
       FormBox["270", TraditionalForm]}, {330, 
       FormBox["330", TraditionalForm]}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{30., 330.}, {-2.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  RotateLabel->False,
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.8585083046913443`*^9, 3.858508313276176*^9}, 
   3.858509758913295*^9, 3.890902770460908*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"10369232-fb3f-4417-8d29-22cb22cb5485"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{925, 640},
WindowMargins->{{81, Automatic}, {Automatic, 33}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"034b8a14-7757-4b51-868c-5cdc70d2f056"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"269817a4-19bf-4f73-935d-a903718166e6"],
Cell[948, 30, 183, 3, 67, "Section",ExpressionUUID->"2a5a0ceb-7fdd-4994-b729-1bb38f7b7d96"],
Cell[1134, 35, 391, 8, 72, "Text",ExpressionUUID->"4f4b0557-04b1-4c6c-8aba-50cc0ae626e9"],
Cell[1528, 45, 357, 8, 53, "Text",ExpressionUUID->"1a77f7cb-a374-455c-b874-934bbe0cd5ed"],
Cell[1888, 55, 6201, 167, 304, "Input",ExpressionUUID->"33166915-659f-43a3-a668-6b1f149a2bbf"],
Cell[8092, 224, 297, 5, 53, "Text",ExpressionUUID->"ba963480-77f1-4d9a-bede-b78d0c2e1c06"],
Cell[8392, 231, 553, 15, 30, "Input",ExpressionUUID->"b22ea0db-be88-4184-955d-2cc7d67fdbd2"],
Cell[8948, 248, 264, 5, 53, "Text",ExpressionUUID->"53e2361e-d680-47ca-b5f2-028cd34b7ed9"],
Cell[9215, 255, 988, 27, 30, "Input",ExpressionUUID->"91c6c36a-2bef-4abf-a636-32fde6ae1390"],
Cell[10206, 284, 281, 5, 53, "Text",ExpressionUUID->"8769580b-7ac5-43b4-bbb9-379c51f28402"],
Cell[10490, 291, 852, 23, 30, "Input",ExpressionUUID->"1f290f11-fbe1-4c32-9ac4-0ff9f49cef7f"],
Cell[11345, 316, 265, 5, 53, "Text",ExpressionUUID->"2c48fec4-9be4-4185-9bfa-b6af1fdb44a1"],
Cell[11613, 323, 220, 4, 30, "Input",ExpressionUUID->"d3cf6e69-ee72-405d-bc7a-2556fa316fdc"],
Cell[11836, 329, 1372, 45, 76, "Text",ExpressionUUID->"619bad11-b858-4312-bc43-5466bf17a6b3"],
Cell[13211, 376, 430, 11, 30, "Input",ExpressionUUID->"49876f28-cc85-4050-b59c-e1ca11f406a5"],
Cell[13644, 389, 489, 13, 30, "Input",ExpressionUUID->"240f5900-c048-410b-89d1-5243c2e82cb0"],
Cell[14136, 404, 550, 15, 30, "Input",ExpressionUUID->"007e1a33-5a6f-4a37-8b21-5da230b9ee9b"],
Cell[14689, 421, 546, 12, 53, "Text",ExpressionUUID->"566e08fa-5b52-4766-9bdd-04f2a347f8ee"],
Cell[CellGroupData[{
Cell[15260, 437, 1962, 54, 94, "Input",ExpressionUUID->"89b32da6-f2fe-4720-a6c3-39f0c50322b7"],
Cell[17225, 493, 64915, 1109, 377, "Output",ExpressionUUID->"45de3c19-81e3-422d-90f0-6382e6290312"]
}, Open  ]],
Cell[82155, 1605, 581, 11, 76, "Text",ExpressionUUID->"5c8377fa-8d4b-4479-8815-9e730256c234"],
Cell[82739, 1618, 585, 11, 76, "Text",ExpressionUUID->"5cd57b6e-1f62-4fea-99b4-25a7e99a26ec"],
Cell[CellGroupData[{
Cell[83349, 1633, 364, 7, 30, "Input",ExpressionUUID->"46d9d4b8-a4d9-45a5-b5bb-71b3b030bdd4"],
Cell[83716, 1642, 65691, 1121, 377, "Output",ExpressionUUID->"0a51d02a-fd1f-4400-85da-1ca2adf90500"]
}, Open  ]],
Cell[149422, 2766, 1385, 27, 78, "Text",ExpressionUUID->"6a1d5b80-6fb8-463f-9fa4-ebd868c96402"],
Cell[150810, 2795, 628, 17, 30, "Input",ExpressionUUID->"cf3dacee-daca-4d52-848b-4cbc375e69ec"],
Cell[151441, 2814, 512, 8, 53, "Text",ExpressionUUID->"27bcb196-d05a-4225-af8a-36d255be8b6b"],
Cell[151956, 2824, 1051, 22, 78, "Input",ExpressionUUID->"e89ff1d2-af93-411f-8d50-89802fcbccdc"],
Cell[153010, 2848, 519, 8, 53, "Text",ExpressionUUID->"e8bd7189-1664-4837-86b4-8c0ffbf98e40"],
Cell[CellGroupData[{
Cell[153554, 2860, 1843, 48, 94, "Input",ExpressionUUID->"1880e32f-bf75-46af-97ea-314da286b414"],
Cell[155400, 2910, 14023, 256, 244, "Output",ExpressionUUID->"865f7aaa-f14c-4c6f-bc56-143d9d96a96d"]
}, Open  ]],
Cell[169438, 3169, 600, 9, 53, "Text",ExpressionUUID->"8a564021-a857-4618-9f06-c17486197e9d"],
Cell[170041, 3180, 744, 20, 30, "Input",ExpressionUUID->"30013113-af3e-4096-b9a6-3bc2c09dd380"],
Cell[170788, 3202, 457, 13, 30, "Input",ExpressionUUID->"f17f958b-b731-4fad-92d7-b7b5791a4528"],
Cell[171248, 3217, 560, 9, 53, "Text",ExpressionUUID->"b46149fd-578f-41b2-b501-1a970a1bd3fe"],
Cell[CellGroupData[{
Cell[171833, 3230, 250, 4, 30, "Input",ExpressionUUID->"432b31e8-6594-4599-b163-f3c2b9ddf8bf"],
Cell[172086, 3236, 14014, 255, 267, "Output",ExpressionUUID->"10369232-fb3f-4417-8d29-22cb22cb5485"]
}, Open  ]]
}
]
*)

